@@ -211,14 +211,13 @@ from abc import ABC, abstractmethod
 from configparser import NoSectionError
 from typing import Any, Dict, Tuple, List, Optional
 
-from ae.core import DEBUG_LEVEL_VERBOSE         # type: ignore
 from ae.updater import check_all                # type: ignore
 from ae.console import ConsoleApp               # type: ignore
 
 from ae.files import FilesRegister, CachedFile  # type: ignore
 
 
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -253,23 +252,18 @@ class MainAppBase(ConsoleApp, ABC):
 
     # generic run-time shortcut references provided by the main app
     framework_app: Any = None                               #: app class instance of the used GUI framework
-    debug_bubble: bool = False                              #: visibility of a popup/bubble showing debugging info
-    info_bubble: Any = None                                 #: optional DebugBubble widget
-
     root_win: Any = None                                    #: app window
     root_layout: Any = None                                 #: app root layout
 
     image_files: Optional[FilesRegister] = None             #: image/icon files
     sound_files: Optional[FilesRegister] = None             #: sound/audio files
 
-    def __init__(self, debug_bubble: bool = False, **console_app_kwargs):
+    def __init__(self, **console_app_kwargs):
         """ create instance of app class.
 
-        :param debug_bubble:        pass True to activate debug bubble.
-        :param console_app_kwargs:  kwargs to be passed to the __init__ method of the super-class / ConsoleApp instance.
+        :param console_app_kwargs:  kwargs to be passed to the __init__ method of :class:`~ae.console_app.ConsoleApp`.
         """
         self.context_path = list()  # init for Literal type recognition - will be overwritten by setup_app_states()
-        self.debug_bubble = debug_bubble
         super().__init__(**console_app_kwargs)
         self.load_app_states()
         self.load_images()
@@ -389,16 +383,7 @@ class MainAppBase(ConsoleApp, ABC):
 
     def load_app_states(self):
         """ load application state for to prepare app.run_app """
-        self.debug_bubble = self.get_opt('debugLevel') >= DEBUG_LEVEL_VERBOSE
-
         app_state = dict()
-        # try:            # if self._cfg_parser.has_section(APP_STATE_SECTION_NAME):
-        #     items = self._cfg_parser.items(APP_STATE_SECTION_NAME)
-        #     for key, state in items:
-        #         lit = Literal(state)        # not working for str literals: , value_type=type(getattr(self, key, "")))
-        #         app_state[key] = lit.value
-        # except NoSectionError:
-        #     self.dpo(f"MainAppBase.load_app_states: ignoring missing config file section {APP_STATE_SECTION_NAME}")
         for key in self.app_state_keys():
             app_state[key] = self.get_var(key, section=APP_STATE_SECTION_NAME)
 
